exgrid v1.0.0 ExGrid.Date
Utility functions used by API client modules
Link to this section Summary
Functions
Compare two dates returning one of the following values:
-1— the first date comes before the second one0— both arguments represent the same date when coalesced to the same timezone.1— the first date comes after the second one
Parses a date string to a datetime struct. Uses YYYY-M-D format by default
Link to this section Functions
Link to this function
compare_dates(first_date, second_date)
Compare two dates returning one of the following values:
-1— the first date comes before the second one0— both arguments represent the same date when coalesced to the same timezone.1— the first date comes after the second one
Link to this function
compare_dates(first_date, second_date, format \\ "{YYYY}-{M}-{D}")
Link to this function
parse_date(date, format \\ "{YYYY}-{M}-{D}")
Parses a date string to a datetime struct. Uses YYYY-M-D format by default.