exgrid v1.0.0 ExGrid
Link to this section Summary
Functions
Validate credentials Sendgrid API needs a user and key to authenticate %{api_key: key, api_user: user}
Link to this section Functions
Link to this function
credentials(arg1)
Validate credentials Sendgrid API needs a user and key to authenticate %{api_key: key, api_user: user}